@@ -1542,7 +1542,7 @@ Will use HTML5 for this SASsession.""")
       chr_upper = {k.upper():v for k,v in charlens.items()}
 
       if type(df.index) != pd.RangeIndex:
-         warnings.warn("Note that Indexes are not transferred over as columns. Only actual coulmns are transferred")
+         warnings.warn("Note that Indexes are not transferred over as columns. Only actual columns are transferred")
 
       for name in df.columns:
          colname = str(name).replace("'", "''")
