@@ -68,6 +68,7 @@ public class saspy2j
    static String               uuid1     = null;
    static SASURI               uri       = null;
    static String               uriStr    = null;
+   static String               reconStr  = null;
    static boolean              reconnect = false;
 
    static org.omg.CORBA.StringHolder qualUserNameHolder = null;
@@ -128,6 +129,7 @@ public class saspy2j
       boolean fndeol = false;
       boolean zero   = false;
       boolean ods    = false;
+      boolean undo   = false;
 
       OctetSeqHolder odsdata = new OctetSeqHolder();
       char[]         in      = new char[4097];
@@ -161,6 +163,8 @@ public class saspy2j
             lrecl = Integer.parseInt(args[x + 1]);
          else if (args[x].equalsIgnoreCase("-logbufsz"))
             logsz = Integer.parseInt(args[x + 1]);
+         else if (args[x].equalsIgnoreCase("-uri"))
+             reconStr = args[x + 1];
          }
 
       iomhosts = iomhost.split(";");
@@ -213,7 +217,7 @@ public class saspy2j
          }
       else
          {
-         if (! spn)
+         if (! spn && uriStr == null)
             omrpw = inp.readLine();
          connect(false, false, false);
          }
@@ -391,9 +395,13 @@ public class saspy2j
                         {
                         cx.close();
                         errp.write("Succesfully disconnected. Be sure to have a valid network connection before submitting anything else.DISCONNECT");
+                        errp.write(uriStr+"END_DISCON");
                         }
                      else
+                        {
                         errp.write("This workspace server is not configured for reconnecting. Did not disconnect.DISCONNECT");
+                        errp.write("END_DISCON");
+                        }
 
                      errp.flush();
                      pgm = pgm.substring(idx + 13 + 33);
@@ -454,11 +462,21 @@ public class saspy2j
                      serr.close();
                      return;
                      }
+                  else if (eol.contains("PRINTTO"))
+                     {
+                     undo = true;
+                     pgm  = pgm.substring(idx + 13 + 33);
+                     }
                   else
                      {
                      pgm = pgm.substring(0, idx);
                      try{
                         lang.Submit(pgm);
+                        if (undo)
+                           lang.Submit("\nproc printto;run;\n%put "+eol.substring(1)+";\n");
+                        else
+                           lang.Submit("\n%put "+eol.substring(1)+";\n");
+                        undo = false;
                         break;
                         }
                      catch(org.omg.CORBA.COMM_FAILURE e)
@@ -467,6 +485,11 @@ public class saspy2j
                            {
                            connect(true, false, false);
                            lang.Submit(pgm);
+                           if (undo)
+                              lang.Submit("\nproc printto;run;\n%put "+eol.substring(1)+";\n");
+                           else
+                              lang.Submit("\n%put "+eol.substring(1)+";\n");
+                           undo = false;
                            break;
                            }
                         else
@@ -659,7 +682,7 @@ public class saspy2j
                         String msg = "We failed in reading the Log\n"+e.getMessage();
                         errp.write(msg);
                         errp.flush();
-                        lang.Submit("%put "+eol.substring(1)+";");
+                        lang.Submit("%put "+eol.substring(1)+";\n");
                         slen = 1;
                         continue;
                         }
@@ -692,6 +715,13 @@ private static void connect(boolean recon, boolean ods, boolean zero) throws IOE
     VariableArray2dOfStringHolder infoPropertyNames  = new VariableArray2dOfStringHolder();
     VariableArray2dOfStringHolder infoPropertyValues = new VariableArray2dOfStringHolder();
 
+    if (reconStr != null)
+       {
+       uri      = SASURI.create(reconStr);
+       recon    = true;
+       reconStr = null;
+       }
+
     if (! zero)
        {
        if (recon)
